/*
 * Dual licensed under the MIT and GPL licenses:
 * 	http://www.opensource.org/licenses/mit-license.php
 * 	http://www.gnu.org/licenses/gpl.html
 */

/**
 * Miniplugin for equalizing box heights.
 *
 * @name            equalHeights
 * @version         0.1
 * @author          Bohdan Ganicky
 * @requires        jQuery
 * @requires        jQuery plugin "toEm" by Scott Jehl (Filament Group)
 * @param {Object}  options Object literal with plugin options.
 */
;(function($) {

	$.fn.equalHeights = function(options) {

		// merge default and user defined options
		options = $.extend({relative: false, alignBottoms: false}, options);

		var tallest = 0;
		var lowest = 0;

		// find out the tallest and (optionally) lowest elements in the set
		this.each(function() {
			var h = $(this).outerHeight();
			if (h > tallest) {
				tallest = h;
			}

			if (options.alignBottoms) {
				var top = $(this).offset()['top'];
				if (top > lowest) {
					lowest = top;
				}
			}
		});

		// iterate again to set the right height
		return this.each(function() {
			var $this = $(this);
			var shift = 0;
			if (options.alignBottoms) {
				shift = $this.offset()['top'] - lowest;
			}
			var total = tallest - ($this.outerHeight() - $this.height()) - shift;
			if (options.relative) {
				total = $(total).toEm({ scope: $this });
			}

			$this.css('height', total);
		});
	};

})(jQuery);
